# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_pve.config as __config
    config = __config
    import pulumi_pve.ha as __ha
    ha = __ha
    import pulumi_pve.pool as __pool
    pool = __pool
    import pulumi_pve.storage as __storage
    storage = __storage
    import pulumi_pve.vm as __vm
    vm = __vm
else:
    config = _utilities.lazy_import('pulumi_pve.config')
    ha = _utilities.lazy_import('pulumi_pve.ha')
    pool = _utilities.lazy_import('pulumi_pve.pool')
    storage = _utilities.lazy_import('pulumi_pve.storage')
    vm = _utilities.lazy_import('pulumi_pve.vm')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "pve",
  "mod": "ha",
  "fqn": "pulumi_pve.ha",
  "classes": {
   "pve:ha:Ha": "Ha"
  }
 },
 {
  "pkg": "pve",
  "mod": "pool",
  "fqn": "pulumi_pve.pool",
  "classes": {
   "pve:pool:Pool": "Pool"
  }
 },
 {
  "pkg": "pve",
  "mod": "storage",
  "fqn": "pulumi_pve.storage",
  "classes": {
   "pve:storage:File": "File"
  }
 },
 {
  "pkg": "pve",
  "mod": "vm",
  "fqn": "pulumi_pve.vm",
  "classes": {
   "pve:vm:Vm": "Vm"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "pve",
  "token": "pulumi:providers:pve",
  "fqn": "pulumi_pve",
  "class": "Provider"
 }
]
"""
)
