# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'FileSourceRawArgs',
    'FileSourceRawArgsDict',
]

MYPY = False

if not MYPY:
    class FileSourceRawArgsDict(TypedDict):
        file_data: pulumi.Input[str]
        """
        The raw data in []byte
        """
        file_name: pulumi.Input[str]
        """
        The name of the file
        """
elif False:
    FileSourceRawArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class FileSourceRawArgs:
    def __init__(__self__, *,
                 file_data: pulumi.Input[str],
                 file_name: pulumi.Input[str]):
        """
        :param pulumi.Input[str] file_data: The raw data in []byte
        :param pulumi.Input[str] file_name: The name of the file
        """
        pulumi.set(__self__, "file_data", file_data)
        pulumi.set(__self__, "file_name", file_name)

    @property
    @pulumi.getter(name="fileData")
    def file_data(self) -> pulumi.Input[str]:
        """
        The raw data in []byte
        """
        return pulumi.get(self, "file_data")

    @file_data.setter
    def file_data(self, value: pulumi.Input[str]):
        pulumi.set(self, "file_data", value)

    @property
    @pulumi.getter(name="fileName")
    def file_name(self) -> pulumi.Input[str]:
        """
        The name of the file
        """
        return pulumi.get(self, "file_name")

    @file_name.setter
    def file_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "file_name", value)


